==> cheq-sst-kotlin-0.4.0-sources.jar: ai/cheq/sst/android/core/settings/SettingsRepository.kt <==
package ai.cheq.sst.android.core.settings

import ai.cheq.sst.android.core.ContextProvider
import ai.cheq.sst.android.core.serializers.settingsDataStore
import ai.cheq.sst.android.protobuf.settings.Settings
import kotlinx.coroutines.flow.firstOrNull
import kotlinx.coroutines.flow.map
import java.util.UUID

internal object SettingsRepository {
    suspend fun readCheqUuid(contextProvider: ContextProvider): String? {
        return readUuid(contextProvider) { settings ->
            settings.cheqUuid ?: null
        }
    }

    suspend fun storeCheqUuid(contextProvider: ContextProvider, uuid: String?) {
        storeUuid(contextProvider, uuid) { l: Settings.Builder, r: String -> l.setCheqUuid(r) }
    }

    suspend fun clearCheqUuid(contextProvider: ContextProvider) {
        try {
            contextProvider.context().settingsDataStore.updateData {
                it.toBuilder().clearCheqUuid().build()
            }
        } catch (_: Exception) {
        }
    }

    suspend fun readDeviceUuid(contextProvider: ContextProvider): String? {
        return readUuid(contextProvider) { settings ->
            settings.deviceUuid ?: null
        }
    }

    suspend fun storeDeviceUuid(contextProvider: ContextProvider, uuid: String?) {
        storeUuid(contextProvider, uuid) { l: Settings.Builder, r: String -> l.setDeviceUuid(r) }
    }

    private suspend fun readUuid(
        contextProvider: ContextProvider, accessor: suspend (value: Settings) -> String?
    ): String? {
        val uuid = read(contextProvider, accessor)
        if (uuid.isNullOrEmpty()) {
            return null
        }
        return try {
            UUID.fromString(uuid).toString()
        } catch (_: Exception) {
            null
        }
    }

    private suspend fun storeUuid(
        contextProvider: ContextProvider,
        uuid: String?,
        setter: suspend (t: Settings.Builder, v: String) -> Settings.Builder
    ) {
        if (!uuid.isNullOrBlank()) {
            try {
                val validatedUuid = UUID.fromString(uuid).toString()
                store(contextProvider, validatedUuid, setter)
            } catch (_: Exception) {
            }
        }
    }

    private suspend fun <R> read(
        contextProvider: ContextProvider, accessor: suspend (value: Settings) -> R
    ): R? {
        return contextProvider.context().settingsDataStore.data.map(accessor).firstOrNull()
    }

    private suspend fun <R> store(
        contextProvider: ContextProvider,
        value: R,
        setter: suspend (settings: Settings.Builder, value: R) -> Settings.Builder
    ) {
        contextProvider.context().settingsDataStore.updateData {
            setter(it.toBuilder(), value).build()
        }
    }
}

==> cheq-sst-kotlin-1.2.0-sources.jar: ai/cheq/sst/android/core/settings/SettingsRepository.kt <==
package ai.cheq.sst.android.core.settings

import ai.cheq.sst.android.core.ContextProvider
import ai.cheq.sst.android.core.internal.ConfigurableContextProvider
import ai.cheq.sst.android.core.serializers.settingsDataStore
import ai.cheq.sst.android.protobuf.settings.Settings
import kotlinx.coroutines.CancellationException
import kotlinx.coroutines.flow.firstOrNull
import kotlinx.coroutines.flow.map
import java.util.UUID

internal object SettingsRepository {
    suspend fun readCheqUuid(contextProvider: ConfigurableContextProvider): String? {
        return contextProvider.provider()?.let {
            readCheqUuid(it)
        }
    }

    suspend fun readCheqUuid(contextProvider: ContextProvider): String? {
        return readUuid(contextProvider) { settings ->
            settings.cheqUuid ?: null
        }
    }

    suspend fun storeCheqUuid(contextProvider: ConfigurableContextProvider, uuid: String?) {
        contextProvider.provider()?.let {
            storeCheqUuid(it, uuid)
        }
    }

    suspend fun storeCheqUuid(contextProvider: ContextProvider, uuid: String?) {
        storeUuid(contextProvider, uuid) { l: Settings.Builder, r: String -> l.setCheqUuid(r) }
    }

    suspend fun clearCheqUuid(contextProvider: ConfigurableContextProvider) {
        try {
            return contextProvider.context()?.let { context ->
                context.settingsDataStore.updateData {
                    it.toBuilder().clearCheqUuid().build()
                }
                return
            } ?: Unit
        } catch (e: CancellationException) {
            throw e
        } catch (_: Exception) {
        }
    }

    suspend fun readDeviceUuid(contextProvider: ConfigurableContextProvider): String? {
        return contextProvider.provider()?.let {
            return readDeviceUuid(it)
        }
    }

    suspend fun readDeviceUuid(contextProvider: ContextProvider): String? {
        return readUuid(contextProvider) { settings ->
            settings.deviceUuid ?: null
        }
    }

    suspend fun storeDeviceUuid(contextProvider: ConfigurableContextProvider, uuid: String?) {
        contextProvider.provider()?.let {
            storeDeviceUuid(it, uuid)
        }
    }

    suspend fun storeDeviceUuid(contextProvider: ContextProvider, uuid: String?) {
        storeUuid(contextProvider, uuid) { l: Settings.Builder, r: String -> l.setDeviceUuid(r) }
    }

    private suspend fun readUuid(
        contextProvider: ContextProvider, accessor: suspend (value: Settings) -> String?
    ): String? {
        val uuid = read(contextProvider, accessor)
        if (uuid.isNullOrEmpty()) {
            return null
        }
        return try {
            UUID.fromString(uuid).toString()
        } catch (e: CancellationException) {
            throw e
        } catch (_: Exception) {
            null
        }
    }

    private suspend fun storeUuid(
        contextProvider: ContextProvider,
        uuid: String?,
        setter: suspend (t: Settings.Builder, v: String) -> Settings.Builder
    ) {
        if (!uuid.isNullOrBlank()) {
            try {
                val validatedUuid = UUID.fromString(uuid).toString()
                store(contextProvider, validatedUuid, setter)
            } catch (e: CancellationException) {
                throw e
            } catch (_: Exception) {
            }
        }
    }

    private suspend fun <R> read(
        contextProvider: ContextProvider, accessor: suspend (value: Settings) -> R
    ): R? {
        return contextProvider.context().settingsDataStore.data.map(accessor).firstOrNull()
    }

    private suspend fun <R> store(
        contextProvider: ContextProvider,
        value: R,
        setter: suspend (settings: Settings.Builder, value: R) -> Settings.Builder
    ) {
        contextProvider.context().settingsDataStore.updateData {
            setter(it.toBuilder(), value).build()
        }
    }
}
